==> fbp-spec-0.6.0.tgz: package/lib/testsuite.js <==
'use strict';

var common, getFileSync, getSuitesSync, jsyaml, loadHTTP, loadYAML, normalize, schemas, validate;

if ((typeof window !== "undefined" && window !== null ? window.jsyaml : void 0) != null) {
  jsyaml = window.jsyaml;
}

if (!jsyaml) {
  jsyaml = require('js-yaml');
}

common = require('./common');

schemas = require('../schema');

exports.validate = validate = function validate(obj) {
  var name, results, schema, tv4;
  tv4 = typeof window !== "undefined" && window !== null ? window.tv4 : void 0;
  if (!tv4) {
    tv4 = require('tv4');
  }
  tv4.reset();
  for (name in schemas) {
    schema = schemas[name];
    tv4.addSchema(schema.id, schema);
  }
  results = tv4.validateMultiple(obj, 'testsfile.json');
  if (results.missing.length) {
    results.passed = false;
  }
  return results;
};

normalize = function normalize(suite) {
  if (!suite.name) {
    // Default name to topic
    suite.name = suite.topic;
  }
  if (!suite.cases) {
    suite.cases = [];
  }
  return suite;
};

exports.create = function (base) {
  return normalize(base);
};

exports.loadYAML = loadYAML = function loadYAML(data) {
  var suite, suites;
  suites = [];
  suite = jsyaml.safeLoadAll(data, function (doc) {
    return suites.push(normalize(doc));
  });
  return suites;
};

loadHTTP = function loadHTTP(url, callback) {
  var req;
  if (common.isBrowser()) {
    req = new XMLHttpRequest();
    req.addEventListener('load', function () {
      var suites;
      suites = loadYAML(this.responseText);
      return callback(null, suites);
    });
    req.addEventListener('error', function () {
      return callback(new Error('Failed to load ' + url + ': ' + this.statusText));
    });
    req.open("get", url, true);
    return req.send();
  } else {
    throw new Error('fbpspec.testsuite: Loading over HTTP not supported on node.js');
  }
};

getFileSync = function getFileSync(test, callback) {
  var c, f, files, fs, path, stat;
  fs = require('fs');
  path = require('path');
  stat = fs.statSync(test);
  if (stat.isDirectory()) {
    files = function () {
      var i, len, ref, results1;
      ref = fs.readdirSync(test);
      results1 = [];
      for (i = 0, len = ref.length; i < len; i++) {
        f = ref[i];
        if (f.indexOf('.yaml') !== -1) {
          results1.push(path.join(test, f));
        }
      }
      return results1;
    }();
    return getSuitesSync(files);
  } else {
    c = fs.readFileSync(test);
    return loadYAML(c);
  }
};

// FIXME: get rid of this...
exports.getSuitesSync = getSuitesSync = function getSuitesSync(tests) {
  var i, len, suites, test;
  if (!Array.isArray(tests)) {
    tests = [tests];
  }
  suites = [];
  for (i = 0, len = tests.length; i < len; i++) {
    test = tests[i];
    suites = suites.concat(getFileSync(test));
  }
  return suites;
};

exports.getSuites = function (tests, callback) {
  var loadTest;
  if (!Array.isArray(tests)) {
    tests = [tests];
  }
  loadTest = function loadTest(test, cb) {
    if (common.startsWith(test, 'http://' || common.startsWith('https://'))) {
      return loadHTTP(test, cb);
    } else {
      return cb(null, getFileSync(test));
    }
  };
  return common.asyncSeries(tests, loadTest, function (err, suitesList) {
    var i, j, len, len1, s, ss, suites;
    if (err) {
      return callback(err);
    }
    // flatten list
    suites = [];
    for (i = 0, len = suitesList.length; i < len; i++) {
      ss = suitesList[i];
      for (j = 0, len1 = ss.length; j < len1; j++) {
        s = ss[j];
        suites.push(s);
      }
    }
    return callback(null, suites);
  });
};

==> fbp-spec-0.6.7.tgz: package/lib/testsuite.js <==
"use strict";

var common, getFileSync, getSuitesSync, jsyaml, loadHTTP, loadYAML, normalize, schemas, validate;

if ((typeof window !== "undefined" && window !== null ? window.jsyaml : void 0) != null) {
  jsyaml = window.jsyaml;
}

if (!jsyaml) {
  jsyaml = require('js-yaml');
}

common = require('./common');
schemas = require('../schema');

exports.validate = validate = function validate(obj) {
  var name, results, schema, tv4;
  tv4 = typeof window !== "undefined" && window !== null ? window.tv4 : void 0;

  if (!tv4) {
    tv4 = require('tv4');
  }

  tv4.reset();

  for (name in schemas) {
    schema = schemas[name];
    tv4.addSchema(schema.id, schema);
  }

  results = tv4.validateMultiple(obj, 'testsfile.json');

  if (results.missing.length) {
    results.passed = false;
  }

  return results;
};

normalize = function normalize(suite) {
  if (!suite.name) {
    // Default name to topic
    suite.name = suite.topic;
  }

  if (!suite.cases) {
    suite.cases = [];
  }

  return suite;
};

exports.create = function (base) {
  return normalize(base);
};

exports.loadYAML = loadYAML = function loadYAML(data) {
  var suite, suites;
  suites = [];
  suite = jsyaml.safeLoadAll(data, function (doc) {
    return suites.push(normalize(doc));
  });
  return suites;
};

loadHTTP = function loadHTTP(url, callback) {
  var req;

  if (common.isBrowser()) {
    req = new XMLHttpRequest();
    req.addEventListener('load', function () {
      var suites;
      suites = loadYAML(this.responseText);
      return callback(null, suites);
    });
    req.addEventListener('error', function () {
      return callback(new Error("Failed to load ".concat(url, ": ").concat(this.statusText)));
    });
    req.open("get", url, true);
    return req.send();
  } else {
    throw new Error('fbpspec.testsuite: Loading over HTTP not supported on node.js');
  }
};

getFileSync = function getFileSync(test, callback) {
  var c, f, files, fs, path, stat;
  fs = require('fs');
  path = require('path');
  stat = fs.statSync(test);

  if (stat.isDirectory()) {
    files = function () {
      var i, len, ref, results1;
      ref = fs.readdirSync(test);
      results1 = [];

      for (i = 0, len = ref.length; i < len; i++) {
        f = ref[i];

        if (f.indexOf('.yaml') !== -1) {
          results1.push(path.join(test, f));
        }
      }

      return results1;
    }();

    return getSuitesSync(files);
  } else {
    c = fs.readFileSync(test);
    return loadYAML(c);
  }
}; // FIXME: get rid of this...


exports.getSuitesSync = getSuitesSync = function getSuitesSync(tests) {
  var i, len, suites, test;

  if (!Array.isArray(tests)) {
    tests = [tests];
  }

  suites = [];

  for (i = 0, len = tests.length; i < len; i++) {
    test = tests[i];
    suites = suites.concat(getFileSync(test));
  }

  return suites;
};

exports.getSuites = function (tests, callback) {
  var loadTest;

  if (!Array.isArray(tests)) {
    tests = [tests];
  }

  loadTest = function loadTest(test, cb) {
    if (common.startsWith(test, 'http://' || common.startsWith('https://'))) {
      return loadHTTP(test, cb);
    } else {
      return cb(null, getFileSync(test));
    }
  };

  return common.asyncSeries(tests, loadTest, function (err, suitesList) {
    var i, j, len, len1, s, ss, suites;

    if (err) {
      return callback(err);
    } // flatten list


    suites = [];

    for (i = 0, len = suitesList.length; i < len; i++) {
      ss = suitesList[i];

      for (j = 0, len1 = ss.length; j < len1; j++) {
        s = ss[j];
        suites.push(s);
      }
    }

    return callback(null, suites);
  });
};
